@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod
 version: 1.4.3
-id: yesod-1.4.3-f305f1bd0a1c829c425775863de16536
-key: yesod_8fLv5vuSLkyKB8SFVID7Ty
+id: yesod-1.4.3-de87987f6cf1fc6d311d5bfb065ca0ca
+key: yesod_6Zj8A8A1sBiJPmoEz0hLmo
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -21,19 +21,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-1.4.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-1.4.3
-hs-libraries: HSyesod-1.4.3-8fLv5vuSLkyKB8SFVID7Ty
+hs-libraries: HSyesod-1.4.3-6Zj8A8A1sBiJPmoEz0hLmo
 depends:
     aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
     blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-extra-1.1.13.1-b0a6afe4d52c8bc50dff37cca54ee4a6
+    conduit-extra-1.1.13.1-eddf025ec4463f8bba96cb21182c4b0f
     data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     fast-logger-2.4.6-262e16722c1e4a82f3b9c171b34b1422
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    monad-logger-0.3.18-8d0d3ee0b0c9e28288fbc3f8ad4970cb
+    monad-logger-0.3.18-868f3e43db7b68548caca5548a3e26c4
     safe-0.3.9-b613242f536083d5bb04920ede356aea
     semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
     shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
@@ -44,14 +44,14 @@ depends:
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
-    wai-extra-3.0.15.1-c6073df16d7e87fd6a9bad9219062fb9
+    wai-extra-3.0.15.1-02499bc73fae2bdcb113927d7f23d5bf
     wai-logger-2.2.7-ce523aca7009dcd9edbddd06c7250c99
     warp-3.2.6-545f6ad0a6172bad2df83f7b250d6e47
-    yaml-0.8.17.1-6800246ed3e006b412aea827bb28629d
-    yesod-auth-1.4.13.2-2f6d751a770f6feb3333cee2daf3d7c3
-    yesod-core-1.4.20.2-6a9eccc8751a316631c6c2141cb80eb5
-    yesod-form-1.4.7.1-b562018d9d1dff8952cde9168801b7f7
-    yesod-persistent-1.4.0.5-629d475d7f77e3630b315100b50a92c4
+    yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
+    yesod-auth-1.4.13.2-45c1d81cc89a916b4d7bd5b138286048
+    yesod-core-1.4.20.2-fe16b4cf33bcf43dffc2858c677b0527
+    yesod-form-1.4.7.1-c61cde6e8bd63b7031b2b5bb0a80077e
+    yesod-persistent-1.4.0.5-b3f205a80e755315b7d38b8b26ea26b2
 haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
 haddock-html: /usr/share/doc/haskell-yesod/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
